# PygletPlayground

> pyglet based OpenGL framework

### Installation
Simply run

    pip install glpg_flowmeadow


### Usage
Import the demo application and run it.

    from glpg_flowmeadow.demos.demo import MyScreen
    
    if __name__ == "__main__":
        app = MyScreen(fullscreen=True)
        app.run()

Move around with ASDF and mouse control. Quit application with Q or ESC.

(Images will follow)